<?php
/**
 * @version		$Id: passwordstrength.php 20196 2011-03-04 02:40:25Z mrichey $
 * @package		plg_auth_email
 * @copyright	Copyright (C) 2005 - 2011 Michael Richey. All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');

class plgUserPasswordStrength extends JPlugin
 {

    /**
     * @param	JForm	$form	The form to be altered.
     * @param	array	$data	The associated data for the form.
     *
     * @return	boolean
     * @since	1.6
     */
    function onContentPrepareForm($form, $data) {
        if (!($form instanceof JForm)) {
            $this->_subject->setError('JERROR_NOT_A_FORM');
            return false;
        }
        
        $app = JFactory::getApplication();
        $validforms=array(
            'com_admin.profile'=>array(
                'inputname'=>'jform[password2]',
                'inputid'=>'password2'
            ),
        		'com_users.profile'=>array(
        				'inputname'=>'jform[password1]',
        				'inputid'=>'password1'
        		),
            'com_users.registration'=>array(
                'inputname'=>'jform[password1]',
                'inputid'=>'password1'
            ),
        );
        if($app->isAdmin()) {
            $validforms['com_users.user']=array(
                'inputname'=>'jform[password]',
                'inputid'=>'password'
            );
            $validforms['com_admin.profile']['inputname']='jform[password2]';
        } else {
            $validforms['com_users.user']='jform[password2]';
        }
        $customforms=$this->params->get('customforms','');
        if(strlen($customforms)) {
            $customforms=array();
            foreach((array)$this->params->get('customforms',array()) as $cf) {
            	$customforms[$cf->formname] = array('inputname'=>$cf->inputname,'inputid'=>$cf->xmlname);
            }
            $validforms = array_merge($validforms,$customforms);
        }
        // Check we are manipulating a valid form.
        $formname = $form->getName();
        if (!in_array($formname, array_keys($validforms))) {
        	return true;
        }

        if($this->chooseSystem()) {
            $doc = JFactory::getDocument();
            $debug = JFactory::getConfig()->get('debug',false)?'':'.min';
            JFactory::getLanguage()->load('plg_user_passwordstrength',JPATH_ADMINISTRATOR);
            JHtml::_('jquery.framework',true);
            $doc->addScript(JURI::root(true).'/media/plg_user_passwordstrength/js/passwordstrength'.$debug.'.js');
            $doc->addScriptOptions('plg_user_passwordstrength',$this->getJsOptions());
            $doc->addScriptDeclaration($this->getJs($validforms[$formname]['inputname']));
            return true;
        } else {
            $form->setFieldAttribute($validforms[$formname]['inputid'],'strengthmeter','true');
            $form->setFieldAttribute($validforms[$formname]['inputid'],'threshold',$this->params->get('threshold',33));
        }
    }
    private function chooseSystem(){
        if($this->params->get('builtinmeter',0)) {
            return false;
        }
        return true;
    }
    private function getJs($inputname){
    	return '(function($){$(document).ready(function($){
			var options = Joomla.getOptions("plg_user_passwordstrength");
			$(\'[name="'.$inputname.'"]\').PasswordStrength(options);
		});})(jQuery);';
    }
    private function getJsOptions() {
        $options=array();
        $options['minLength']=(int)$this->params->get('minLength',6);
        $options['maxLength']=(int)$this->params->get('maxLength',15);
        if($this->params->get('usetext',1)) {
            $options['useText']=true;
            JText::script('PLG_USER_PASSWORDSTRENGTH_TEXT_POOR');
            JText::script('PLG_USER_PASSWORDSTRENGTH_TEXT_WEAK');
            JText::script('PLG_USER_PASSWORDSTRENGTH_TEXT_MEDIUM');
            JText::script('PLG_USER_PASSWORDSTRENGTH_TEXT_STRONG');
        } else {
            $options['useText']=false;
        }
        if($this->params->get('usedefaultstrength',1)) {
        	$userparams = JComponentHelper::getParams('com_users');
        	$options['defaultstrength'] = 1;
        	$options['minlength']=(int)$userparams->get('minimum_length',4);
        	$options['minintegers']=(int)$userparams->get('minimum_integers',0);
        	$options['minsymbols']=(int)$userparams->get('minimum_symbols',0);
        	$options['minuppercase']=(int)$userparams->get('minimum_uppercase',0);
        } else {
        	$options['defaultstrength'] = 0;
        	$options['weakRegEx']=$this->params->get('weakregex','([a-z]{1}[A-Z]{1})|([A-Z]{1}[a-z]{1})[^\s]');
        	$options['mediumRegEx']=$this->params->get('mediumregex','[0-9]{1}');
        	$options['strongRegEx']=$this->params->get('strongregex','[^a-zA-Z0-9]{1}');
        }
        return $options;
    }
}
